@@ -1,4 +1,5 @@
-from .base import BaseComparer, ReadOnlyCellTypes, SearchCellDefinition
+from typing import Optional
+from .base import BaseComparer, ReadOnlyCellTypes, SearchCell
 
 
 class FontSizeCompare(BaseComparer):
@@ -7,19 +8,19 @@ class FontSizeCompare(BaseComparer):
         super().__init__(weigth=weigth)
 
     def _compare(
-        self, cell: ReadOnlyCellTypes, search_cell: SearchCellDefinition
-    ) -> int:
+        self, cell: ReadOnlyCellTypes, search_cell: SearchCell
+    ) -> Optional[int]:
 
         if cell.font is None and search_cell.font is None:
-            return 0
+            return 100
         elif cell.font is not None and search_cell.font is None:
             return 100
         elif cell.font is None and search_cell.font is not None:
-            return 100
+            return 0
 
         diff_sz = abs(cell.font.sz - search_cell.font.sz)  # type: ignore
 
         if diff_sz > self.font_size_range:
-            return 100
+            return 0
         else:
-            return int((diff_sz / self.font_size_range) * 100)
+            return int(( self.font_size_range/ diff_sz) * 100)
